==> org.apache.sling.servlets.post-2.3.33-20191001.180847-7-sources.jar: org/apache/sling/servlets/post/impl/PostResponseWithErrorHandling.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sling.servlets.post.impl;

import java.io.IOException;

import javax.servlet.http.HttpServletResponse;

import org.apache.sling.api.SlingHttpServletRequest;
import org.apache.sling.servlets.post.HtmlResponse;
import org.apache.sling.servlets.post.PostResponse;
import org.apache.sling.servlets.post.PostResponseCreator;
import org.apache.sling.servlets.post.SlingPostConstants;
import org.osgi.service.component.annotations.Component;

@Component(service = PostResponseCreator.class,
    property = {
            "service.vendor=The Apache Software Foundation"
    })
public class PostResponseWithErrorHandling implements PostResponseCreator {

	@Override
    public PostResponse createPostResponse(SlingHttpServletRequest request) {
		if (isSendError(request)) {
			return new HtmlResponse() {

				@Override
				protected void doSend(HttpServletResponse response) throws IOException {
					if (!this.isSuccessful()) {
						response.sendError(this.getStatusCode(), this.getError().toString());
						return;
					}else{
						super.doSend(response);
					}
				}
			};
		}else{
			return null;
		}
	}

	protected boolean isSendError(SlingHttpServletRequest request){
		boolean sendError=false;
		String sendErrorParam=request.getParameter(SlingPostConstants.RP_SEND_ERROR);
		if (sendErrorParam!=null && "true".equalsIgnoreCase(sendErrorParam)){
			sendError=true;
		}
		return sendError;
	}
}

==> org.apache.sling.servlets.post-2.5.0-sources.jar: org/apache/sling/servlets/post/impl/PostResponseWithErrorHandling.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sling.servlets.post.impl;

import java.io.IOException;

import javax.servlet.http.HttpServletResponse;

import org.apache.sling.api.SlingHttpServletRequest;
import org.apache.sling.servlets.post.HtmlResponse;
import org.apache.sling.servlets.post.PostResponse;
import org.apache.sling.servlets.post.PostResponseCreator;
import org.apache.sling.servlets.post.SlingPostConstants;

/**
 * @deprecated SLING-10006 - this component is now deprecated no longer registered as an
 * OSGi component as the error handling is now done in a different way in {@link SlingPostServlet#createPostResponse(SlingHttpServletRequest)}.
 */
@Deprecated
public class PostResponseWithErrorHandling implements PostResponseCreator {

	@Override
    public PostResponse createPostResponse(SlingHttpServletRequest request) {
		if (isSendError(request)) {
			return new HtmlResponse() {

				@Override
				protected void doSend(HttpServletResponse response) throws IOException {
					if (!this.isSuccessful()) {
						response.sendError(this.getStatusCode(), this.getError().toString());
						return;
					}else{
						super.doSend(response);
					}
				}
			};
		}else{
			return null;
		}
	}

	protected boolean isSendError(SlingHttpServletRequest request){
		boolean sendError=false;
		String sendErrorParam=request.getParameter(SlingPostConstants.RP_SEND_ERROR);
		if (sendErrorParam!=null && "true".equalsIgnoreCase(sendErrorParam)){
			sendError=true;
		}
		return sendError;
	}
}
